/*************************************************************
 *
 *  MathJax/localization/mk/MathMenu.js
 *
 *  Copyright (c) 2009-2019 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
MathJax.Localization.addTranslation("mk","MathMenu",{
        version: "2.7.7",
        isLoaded: true,
        strings: {
          Show: "\u041F\u0440\u0438\u043A\u0430\u0436\u0438 \u0458\u0430 \u043C\u0430\u0442\u0435\u043C\u0430\u0442\u0438\u043A\u0430\u0442\u0430 \u043A\u0430\u043A\u043E",
          MathMLcode: "MathML-\u043A\u043E\u0434",
          OriginalMathML: "\u0418\u0437\u0432\u043E\u0440\u0435\u043D MathML",
          TeXCommands: "TeX-\u043D\u0430\u0440\u0435\u0434\u0431\u0438",
          AsciiMathInput: "AsciiMathML-\u0432\u043D\u043E\u0441",
          Original: "\u0418\u0437\u0432\u043E\u0440\u0435\u043D \u043E\u0431\u043B\u0438\u043A",
          ErrorMessage: "\u0418\u0437\u0432\u0435\u0441\u0442\u0443\u0432\u0430\u045A\u0435 \u0437\u0430 \u0433\u0440\u0435\u0448\u043A\u0430",
          Annotation: "\u041F\u0440\u0438\u0431\u0435\u043B\u0435\u0448\u043A\u0438",
          TeX: "TeX",
          StarMath: "StarMath",
          Maple: "Maple",
          ContentMathML: "\u0421\u043E\u0434\u0440\u0436\u0438\u043D\u0441\u043A\u0438 MathML",
          OpenMath: "OpenMath",
          texHints: "\u041F\u0440\u0438\u043A\u0430\u0436\u0443\u0432\u0430\u0458 \u043F\u043E\u043C\u043E\u0448\u043D\u0438 \u043F\u0440\u0435\u0434\u043B\u043E\u0437\u0438 \u043E\u0434 TeX \u0432\u043E MathML",
          Settings: "\u041C\u0430\u0442\u0435\u043C\u0430\u0442\u0438\u0447\u043A\u0438 \u043F\u043E\u0441\u0442\u0430\u0432\u043A\u0438",
          ZoomTrigger: "\u0417\u0433\u043E\u043B\u0435\u043C\u0443\u0432\u0430\u045A\u0435",
          Hover: "\u0421\u0442\u0440\u0435\u043B\u043A\u0430 \u0432\u0440\u0437 \u0441\u043E\u0434\u0440\u0436\u0438\u043D\u0430\u0442\u0430",
          Click: "\u0421\u0442\u0438\u0441\u043E\u043A",
          DoubleClick: "\u0414\u0432\u043E\u0435\u043D \u0441\u0442\u0438\u0441\u043E\u043A",
          NoZoom: "\u0411\u0435\u0437 \u0437\u0433\u043E\u043B\u0435\u043C\u0443\u0432\u0430\u045A\u0435",
          TriggerRequires: "\u0417\u0430 \u0434\u0430 \u0433\u043E \u0437\u0433\u043E\u043B\u0435\u043C\u0438\u0442\u0435 \u0438\u0441\u043F\u0438\u0441\u043E\u0442:",
          Option: "\u041C\u043E\u0436\u043D\u043E\u0441\u0442",
          Alt: "Alt",
          Command: "\u2318",
          Control: "Ctrl",
          Shift: "Shift",
          ZoomFactor: "\u0427\u0438\u043D\u0438\u0442\u0435\u043B \u2014 \u041F\u0440\u0438\u0431\u043B\u0438\u0436\u0443\u0432\u0430\u045A\u0435",
          Renderer: "\u041C\u0430\u0442\u0435\u043C\u0430\u0442\u0438\u0447\u043A\u0438 \u0438\u0441\u043F\u0438\u0448\u0443\u0432\u0430\u0447",
          MPHandles: "\u041D\u0435\u043A\u0430 MathPlayer \u0440\u0430\u0431\u043E\u0442\u0438 \u0441\u043E:",
          MenuEvents: "\u041F\u043E\u0441\u0442\u0430\u043F\u043A\u0438 \u0441\u043E \u043C\u0435\u043D\u0438\u0442\u043E",
          MouseEvents: "\u041F\u043E\u0441\u0442\u0430\u043F\u043A\u0438 \u0441\u043E \u0433\u043B\u0443\u0448\u0435\u0446\u043E\u0442",
          MenuAndMouse: "\u041F\u043E\u0441\u0442\u0430\u043F\u043A\u0438 \u0441\u043E \u043C\u0435\u043D\u0438\u0442\u043E \u0438 \u0433\u043B\u0443\u0448\u0435\u0446\u043E\u0442",
          FontPrefs: "\u041D\u0430\u0433\u043E\u0434\u0443\u0432\u0430\u045A\u0430 \u043D\u0430 \u0444\u043E\u043D\u0442\u043E\u0442",
          ForHTMLCSS: "\u0417\u0430 HTML-CSS:",
          Auto: "\u0410\u0432\u0442\u043E\u043C\u0430\u0442\u0441\u043A\u0438",
          TeXLocal: "TeX (\u043C\u0435\u0441\u043D\u043E)",
          TeXWeb: "TeX (\u043C\u0440\u0435\u0436\u043D\u043E)",
          TeXImage: "TeX (\u0441\u043B\u0438\u043A\u0430)",
          STIXLocal: "STIX (\u043C\u0435\u0441\u043D\u043E)",
          STIXWeb: "STIX (\u043C\u0440\u0435\u0436\u043D\u043E)",
          AsanaMathWeb: "Asana Math (\u043C\u0440\u0435\u0436\u043D\u043E)",
          GyrePagellaWeb: "Gyre Pagella (\u043C\u0440\u0435\u0436\u043D\u043E)",
          GyreTermesWeb: "Gyre Termes (\u043C\u0440\u0435\u0436\u043D\u043E)",
          LatinModernWeb: "Latin Modern (\u043C\u0440\u0435\u0436\u043D\u043E)",
          NeoEulerWeb: "Neo Euler (\u043C\u0440\u0435\u0436\u043D\u043E)",
          ContextMenu: "\u041A\u043E\u043D\u0442\u0435\u043A\u0441\u0442\u043D\u043E \u043C\u0435\u043D\u0438",
          Browser: "\u041F\u0440\u0435\u043B\u0438\u0441\u0442\u0443\u0432\u0430\u0447",
          Scale: "\u041F\u0440\u0438\u043A\u0430\u0436\u0443\u0432\u0430 \u0458\u0430 \u0441\u0435\u0442\u0430 \u043C\u0430\u0442\u0435\u043C\u0430\u0442\u0438\u043A\u0430 \u0432\u043E \u0440\u0430\u0437\u043C\u0435\u0440...",
          Discoverable: "\u0418\u0441\u0442\u0430\u043A\u043D\u0443\u0432\u0430\u0458 (\u043F\u043E\u0442\u0446\u0440\u0442\u0443\u0432\u0430\u0458) \u043F\u0440\u0438 \u043E\u0434\u0435\u045A\u0435 \u0441\u043E \u0441\u0442\u0440\u0435\u043B\u043A\u0430\u0442\u0430 \u0432\u0440\u0437 \u0441\u043E\u0434\u0440\u0436\u0438\u043D\u0430\u0442\u0430",
          Locale: "\u0408\u0430\u0437\u0438\u043A",
          LoadLocale: "\u0412\u0447\u0438\u0442\u0430\u0458 \u043E\u0434 URL ...",
          About: "\u0417\u0430 MathJax",
          Help: "\u041F\u043E\u043C\u043E\u0448 \u0441\u043E MathJax",
          localTeXfonts: "\u043A\u043E\u0440\u0438\u0441\u0442\u0438 TeX-\u0444\u043E\u043D\u0442\u043E\u0432\u0438",
          webTeXfonts: "\u043A\u043E\u0440\u0438\u0441\u0442\u0438 \u043C\u0440\u0435\u0436\u043D\u0438 TeX-\u0444\u043E\u043D\u0442\u043E\u0432\u0438",
          imagefonts: "\u043A\u043E\u0440\u0438\u0441\u0442\u0438 \u0441\u043B\u0438\u043A\u043E\u0432\u043D\u0438 \u0444\u043E\u043D\u0442\u043E\u0432\u0438",
          localSTIXfonts: "\u043A\u043E\u0440\u0438\u0441\u0442\u0438 \u043C\u0435\u0441\u043D\u0438 STIX-\u0444\u043E\u043D\u0442\u043E\u0432\u0438",
          webSVGfonts: "\u043A\u043E\u0440\u0438\u0441\u0442\u0438 \u043C\u0440\u0435\u0436\u043D\u0438 SVG-\u0444\u043E\u043D\u0442\u043E\u0432\u0438",
          genericfonts: "\u043A\u043E\u0440\u0438\u0441\u0442\u0438 \u043E\u043F\u0448\u0442\u043E\u043D\u0430\u043C\u0435\u043D\u0441\u043A\u0438 \u0443\u043D\u0438\u043A\u043E\u0434\u043D\u0438 \u0444\u043E\u043D\u0442\u043E\u0432\u0438",
          wofforotffonts: "WOFF- \u0438\u043B\u0438 OTF-\u0444\u043E\u043D\u0442\u043E\u0432\u0438",
          eotffonts: "EOT-\u0444\u043E\u043D\u0442\u043E\u0432\u0438",
          svgfonts: "SVG-\u0444\u043E\u043D\u0442\u043E\u0432\u0438",
          WebkitNativeMMLWarning: "\u0412\u0430\u0448\u0438\u043E\u0442 \u043F\u0440\u0435\u043B\u0438\u0441\u0442\u0443\u0432\u0430\u0447 \u043D\u0435\u043C\u0430 \u0432\u0433\u0440\u0430\u0434\u0435\u043D\u0430 \u043F\u043E\u0434\u0434\u0440\u0448\u043A\u0430 \u0437\u0430 MathML, \u043F\u0430 \u0437\u0430\u0442\u043E\u0430 \u0430\u043A\u043E \u0441\u0435 \u043F\u0440\u0435\u0444\u0440\u043B\u0438\u0442\u0435 \u043D\u0430 \u043D\u0435\u0433\u043E, \u043C\u0430\u0442\u0435\u043C\u0430\u0442\u0438\u0447\u043A\u0438\u0442\u0435 \u0441\u043E\u0434\u0440\u0436\u0438\u043D\u0438 \u043C\u043E\u0436\u0430\u0442 \u0434\u0430 \u0441\u0442\u0430\u043D\u0430\u0442 \u043D\u0435\u0447\u0438\u0442\u043B\u0438\u0432\u0438.",
          MSIENativeMMLWarning: "Internet Explorer \u0433\u043E \u0431\u0430\u0440\u0430 \u0434\u043E\u0434\u0430\u0442\u043E\u043A\u043E\u0442 MathPlayer \u0437\u0430 \u0434\u0430 \u043C\u043E\u0436\u0435 \u0434\u0430 \u0440\u0430\u0431\u043E\u0442\u0438 \u0441\u043E MathML.",
          OperaNativeMMLWarning: "Opera \u0438\u043C\u0430 \u043E\u0433\u0440\u0430\u043D\u0438\u0447\u0435\u043D\u0430 \u043F\u043E\u0434\u0434\u0440\u0448\u043A\u0430 \u0437\u0430 MathML, \u0448\u0442\u043E \u0437\u043D\u0430\u0447\u0438 \u0434\u0435\u043A\u0430 \u0438\u0441\u043F\u0438\u0441\u043E\u0442 \u043D\u0430 \u043D\u0435\u043A\u043E\u0438 \u0438\u0437\u0440\u0435\u0437\u0438 \u043C\u043E\u0436\u0435 \u0434\u0430 \u0431\u0438\u0434\u0435 \u043B\u043E\u0448.",
          SafariNativeMMLWarning: "\u0412\u0433\u0440\u0430\u0434\u0435\u043D\u0430\u0442\u0430 \u043F\u043E\u0434\u0434\u0440\u0448\u043A\u0430 \u0437\u0430 MathML \u0432\u043E \u0432\u0430\u0448\u0438\u043E\u0442 \u043F\u0440\u0435\u043B\u0438\u0441\u0442\u0443\u0432\u0430\u0447 \u043D\u0435 \u0433\u0438 \u0438\u043C\u0430 \u0441\u0438\u0442\u0435 \u0444\u0443\u043D\u043A\u0446\u0438\u0438 \u043D\u0430 MathJax, \u043F\u0430 \u0437\u0430\u0442\u043E\u0430 \u0438\u0441\u043F\u0438\u0441\u043E\u0442 \u043D\u0430 \u043D\u0435\u043A\u043E\u0438 \u0438\u0437\u0440\u0435\u0437\u0438 \u043C\u043E\u0436\u0435 \u0434\u0430 \u0431\u0438\u0434\u0435 \u043B\u043E\u0448.",
          FirefoxNativeMMLWarning: "\u0412\u0433\u0440\u0430\u0434\u0435\u043D\u0430\u0442\u0430 \u043F\u043E\u0434\u0434\u0440\u0448\u043A\u0430 \u0437\u0430 MathML \u0432\u043E \u0432\u0430\u0448\u0438\u043E\u0442 \u043F\u0440\u0435\u043B\u0438\u0441\u0442\u0443\u0432\u0430\u0447 \u043D\u0435 \u0433\u0438 \u0438\u043C\u0430 \u0441\u0438\u0442\u0435 \u0444\u0443\u043D\u043A\u0446\u0438\u0438 \u043D\u0430 MathJax, \u043F\u0430 \u0437\u0430\u0442\u043E\u0430 \u0438\u0441\u043F\u0438\u0441\u043E\u0442 \u043D\u0430 \u043D\u0435\u043A\u043E\u0438 \u0438\u0437\u0440\u0435\u0437\u0438 \u043C\u043E\u0436\u0435 \u0434\u0430 \u0431\u0438\u0434\u0435 \u043B\u043E\u0448.",
          MSIESVGWarning: "Internet Explorer \u043D\u0435\u043C\u0430 \u043F\u043E\u0434\u0434\u0440\u0448\u043A\u0430 \u0437\u0430 SVG \u0432\u043E \u0432\u0435\u0440\u0437\u0438\u0438\u0442\u0435 \u043F\u0440\u0435\u0434 IE9 \u0438\u043B\u0438 \u043A\u043E\u0433\u0430 \u0435\u043C\u0443\u043B\u0438\u0440\u0430 IE8 \u0438\u043B\u0438 \u043F\u043E\u0441\u0442\u0430\u0440\u0438 \u0432\u0435\u0440\u0437\u0438\u0438. \u0417\u0430\u0442\u043E\u0430, \u043C\u0430\u0442\u0435\u043C\u0430\u0442\u0438\u0447\u043A\u0438\u0442\u0435 \u0441\u043E\u0434\u0440\u0436\u0438\u043D\u0438 \u043D\u0435\u043C\u0430 \u0434\u0430 \u0441\u0435 \u0438\u0441\u043F\u0438\u0448\u0443\u0432\u0430\u0430\u0442 \u043F\u0440\u0430\u0432\u0438\u043B\u043D\u043E.",
          LoadURL: "\u0412\u0447\u0438\u0442\u0430\u0458 \u0433\u0438 \u043F\u0440\u0435\u0432\u043E\u0434\u043D\u0438\u0442\u0435 \u043F\u043E\u0434\u0430\u0442\u043E\u0446\u0438 \u043E\u0434 \u0441\u043B\u0435\u0434\u043D\u0430\u0432\u0430 URL:",
          BadURL: "URL-\u0430\u0434\u0440\u0435\u0441\u0430\u0442\u0430 \u0442\u0440\u0435\u0431\u0430 \u0434\u0430 \u0431\u0438\u0434\u0435 \u043F\u043E\u0434\u0430\u0442\u043E\u0442\u0435\u043A\u0430 \u0441\u043E JavaScript-\u043F\u043E\u0434\u0430\u0442\u043E\u0446\u0438 \u0448\u0442\u043E \u0433\u0438 \u043E\u043F\u0440\u0435\u0434\u0435\u043B\u0443\u0432\u0430\u0430\u0442 \u043F\u0440\u0435\u0432\u043E\u0434\u043D\u0438\u0442\u0435 \u043F\u043E\u0434\u0430\u0442\u043E\u0446\u0438 \u0437\u0430 MathJax. JavaScript-\u043F\u043E\u0434\u0430\u0442\u043E\u0442\u0435\u043A\u0438\u0442\u0435 \u0442\u0440\u0435\u0431\u0430 \u0434\u0430 \u0437\u0430\u0432\u0440\u0448\u0443\u0432\u0430\u0430\u0442 \u0441\u043E \u043D\u0430\u0441\u0442\u0430\u0432\u043A\u0430\u0442\u0430 \u201E.js\u201C",
          BadData: "\u041D\u0435 \u0443\u0441\u043F\u0435\u0430\u0432 \u0434\u0430 \u0433\u0438 \u0432\u0447\u0438\u0442\u0430\u043C \u043F\u0440\u0435\u0432\u043E\u0434\u043D\u0438\u0442\u0435 \u043F\u043E\u0434\u0430\u0442\u043E\u0446\u0438 \u043E\u0434 %1",
          SwitchAnyway: "\u0421\u0435\u043F\u0430\u043A \u0434\u0430 \u0433\u043E \u0441\u043C\u0435\u043D\u0430\u043C \u0438\u0441\u043F\u0438\u0448\u0443\u0432\u0430\u0447\u043E\u0442?\n\n(\u041E\u041A \u0437\u0430 \u0434\u0430 \u0441\u0435 \u0441\u043C\u0435\u043D\u0438 \u0438\u043B\u0438 \u041E\u0422\u041A\u0410\u0416\u0418 \u0437\u0430 \u0434\u0430 \u043F\u0440\u043E\u0434\u043E\u043B\u0436\u0438\u0442\u0435 \u0441\u043E \u043F\u043E\u0441\u0442\u043E\u0435\u0447\u043A\u0438\u043E\u0442)",
          ScaleMath: "\u0420\u0430\u0437\u043C\u0435\u0440 \u043D\u0430 \u0441\u0435\u0442\u0430 \u043C\u0430\u0442\u0435\u043C\u0430\u0442\u0438\u043A\u0430 (\u0432\u043E \u043E\u0434\u043D\u043E\u0441 \u043D\u0430 \u043E\u043A\u043E\u043B\u043D\u0438\u043E\u0442 \u0442\u0435\u043A\u0441\u0442, \u043A\u0430\u043A\u043E \u043F\u043E\u0441\u0442\u043E\u0442\u043E\u043A):",
          NonZeroScale: "\u0420\u0430\u0437\u043C\u0435\u0440\u043E\u0442 \u043D\u0435 \u043C\u043E\u0436\u0435 \u0434\u0430 \u0431\u0438\u0434\u0435 \u043D\u0443\u043B\u0430",
          PercentScale: "\u0420\u0430\u0437\u043C\u0435\u0440\u043E\u0442 \u0442\u0440\u0435\u0431\u0430 \u0434\u0430 \u0435 \u0438\u0437\u0440\u0430\u0437\u0435\u043D \u0432\u043E \u043F\u043E\u0441\u0442\u043E\u0442\u043E\u043A (\u043D\u0430 \u043F\u0440. 120%%)",
          IE8warning: "\u0421\u043E \u043E\u0432\u0430 \u045C\u0435 \u0433\u0438 \u0438\u0441\u043A\u043B\u0443\u0447\u0438\u0442\u0435 \u043C\u043E\u0436\u043D\u043E\u0441\u0442\u0438\u0442\u0435 \u043E\u0434 \u043C\u0435\u043D\u0438\u0442\u043E \u0438 \u043C\u0435\u043D\u0443\u0432\u0430\u045A\u0435\u0442\u043E \u043D\u0430 \u0433\u043E\u043B\u0435\u043C\u0438\u043D\u0430\u0442\u0430 \u0432\u043E MathJax, \u043D\u043E \u043C\u0435\u043D\u0438\u0442\u043E \u043C\u043E\u0436\u0435\u0442\u0435 \u0434\u0430 \u0433\u043E \u0434\u043E\u0431\u0438\u0435\u0442\u0435 \u0441\u043E Alt-\u0441\u0442\u0438\u0441\u043E\u043A \u043D\u0430 \u043D\u0435\u043A\u043E\u0458 \u0438\u0437\u0440\u0430\u0437.\n\n\u041D\u0430\u0432\u0438\u0441\u0442\u0438\u043D\u0430 \u0434\u0430 \u0433\u0438 \u0438\u0437\u043C\u0435\u0430\u043C \u043F\u043E\u0441\u0442\u0430\u0432\u043A\u0438\u0442\u0435 \u043D\u0430 MathPlayer?",
          IE9warning: "\u041A\u043E\u043D\u0442\u0435\u043A\u0441\u0442\u043D\u043E\u0442\u043E \u043C\u0435\u043D\u0438 \u043D\u0430 MathJax \u045C\u0435 \u0431\u0438\u0434\u0435 \u0438\u0441\u043A\u043B\u0443\u0447\u0435\u043D\u043E, \u043D\u043E \u043C\u043E\u0436\u0435\u0442\u0435 \u0434\u0430 \u043D\u0430\u043F\u0440\u0430\u0432\u0438\u0442\u0435 Alt-\u0441\u0442\u0438\u0441\u043E\u043A \u043D\u0430 \u0438\u0437\u0440\u0430\u0437\u043E\u0442 \u0437\u0430 \u0434\u0430 \u0433\u043E \u0434\u043E\u0431\u0438\u0435\u0442\u0435 \u043C\u0435\u043D\u0438\u0442\u043E.",
          NoOriginalForm: "\u041D\u0435\u043C\u0430 \u0438\u0437\u0432\u043E\u0440\u0435\u043D \u043E\u0431\u043B\u0438\u043A \u043D\u0430 \u0440\u0430\u0441\u043F\u043E\u043B\u0430\u0433\u0430\u045A\u0435",
          Close: "\u0417\u0430\u0442\u0432\u043E\u0440\u0438",
          EqSource: "\u0418\u0437\u0432\u043E\u0440 \u043D\u0430 \u0440\u0430\u0432\u0435\u043D\u043A\u0438\u0442\u0435 \u043D\u0430 MathJax",
          CloseAboutDialog: "\u0417\u0430\u0442\u0432\u043E\u0440\u0438 \u0433\u043E \u0434\u0438\u0458\u0430\u043B\u043E\u0433\u043E\u0442 \u0437\u0430 MathJax",
          FastPreview: "\u0411\u0440\u0437 \u043F\u0440\u0435\u0433\u043B\u0435\u0434",
          AssistiveMML: "\u041F\u043E\u043C\u043E\u0448\u0435\u043D MathML",
          InTabOrder: "\u0412\u043A\u043B\u0443\u0447\u0438 \u0432\u043E \u0440\u0435\u0434\u043E\u0441\u043B\u0435\u0434\u043E\u0442 \u043D\u0430 \u0458\u0430\u0437\u0438\u0447\u0438\u045A\u0430"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/mk/MathMenu.js");
